credentials

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 23, 2023 License: Apache-2.0 Imports: 0 Imported by: 0

README

types/credentials

The types/credentials package contains interfaces used to create cloud provider-specific SDK connections and sessions

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Credentials

type Credentials interface {
	// Session returns an object that can be fed to a Manager to create a
	// session in a cloud provider's SDK.
	Session(...interface{}) interface{}
}

Jump to